/*
 * GWT - General Windowing Toolkit
 *
 * Copyright (C) 1998 MenTaLguY - mentalg@geocities.com
 *                    Rodolphe Ortalo - ortalo@laas.fr
 *                    Tristan Wibberley - bloater@ps.cus.umist.ac.uk
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Log: gwt_types.h,v $
 * Revision 1.8  1999/05/24 00:28:53  marcus
 * Fixed includes.
 *
 * Revision 1.7  1999/05/20 20:34:23  ortalo
 * Several bugs corrections and small improvements.
 *
 * Revision 1.6  1999/05/13 20:01:38  ortalo
 * New version of libgwt. Now using LibGII for input management.
 * Some drawing functions implemented. Visibility management should
 * be rather okay. Still some work to do, but now, your eyes can
 * look at some drawings... not only code. ;-)
 *
 * Revision 1.5  1998/11/17 15:13:28  tristan
 *
 * Changed my email address
 *
 * Revision 1.4  1998/09/02 02:21:56  tristan
 * Loadsa great stuff done. Visible/invalid regions,
 *  copy on move - fixed tt_region.c too!
 *
 * Revision 1.3  1998/08/23 18:57:17  ortalo
 * Minor editing (mainly comments).
 *
 * Revision 1.2  1998/08/11 22:09:11  ortalo
 * Incorporated the work made by Tristan Wibberley. Still in alpha
 * development state.
 *
 * Revision 1.1  1998/07/09 18:38:39  ortalo
 * Initial integration of libgwt in the GGI repository.
 * This is experimental code, for your eyes only !
 * (Don't execute... ;-)
 *
 */

#ifndef __GGI_GWT_TYPES_H
#define __GGI_GWT_TYPES_H

#include <ggi/gii.h>
#include <ggi/ggi.h>

typedef int gwt_id_t;
#define GWT_NULL_ID 0;

struct _gwt_window;
typedef struct _gwt_window gwt_window;
typedef gwt_window *gwt_window_t;

#include "region.h"

struct _gwt_zorder {
  gwt_window_t zbottom, ztop;
};
typedef struct _gwt_zorder gwt_zorder;

struct _gwt_window {
  ggi_visual_t visual; /* Root visual being used to display */  

  gii_input_t input;  /* Per-window input queue */
  int ptr_x;          /* Current absolute pointer position */
  int ptr_y;          /* (NB: IN WINDOW COORDINATES!) */
  ggi_event_mask accepts; /* Input event mask TODO: Update to gii */
	
  /* Window-specific graphic context */
  ggi_pixel foreground; /* foreground color */
  ggi_pixel background; /* backgroun color */

  int hidden;
  int implicitly_hidden;
	
  gwt_window_t wparent;
  int level;
	
  ggi_coord origin;
  gwt_region_t geometry;            /* window geometry :-) */
  gwt_region_t visible;             /* real visible region */
  gwt_region_t potentially_visible; /* children not included */
  gwt_region_t clipping;            /* clipping region */
  gwt_region_t drawing;             /* drawing region */

  gwt_region_t invalid;

  /* Focussed sub-window */
  gwt_window_t focuss;

  /* Sub-windows Z-Order */
  gwt_zorder zorder;
  /* A window needs pointers to be part of a Z-Order */
  gwt_window_t zprev, znext;

  /* Private data */
  void *priv;

  /* Unique ID */
  gwt_id_t id;
};

typedef struct _gwtprivate { char priv[123];} gwtprivate;

#endif /* __GGI_GWT_TYPES_H */
